@@ -122,15 +122,19 @@ class OvercloudRoleCount(Base):
     # Overcloud in which the role is being deployed
     overcloud_id = \
         Column(Integer,
-               ForeignKey('%s.id' % TABLE_OVERCLOUD),
+               ForeignKey('%s.id' % TABLE_OVERCLOUD, ondelete='CASCADE'),
                nullable=False)
 
     # Number of nodes of this configuration that should be deployed
     num_nodes = Column(Integer, nullable=False)
 
+    # Reference to the full role (this is not the foreign key relationship,
+    # that's overcloud_role_id above, this is to eager load the role data).
+    overcloud_role = relationship(OvercloudRole.__name__)
+
     def __eq__(self, other):
-        return self.overcloud_role_id == other.overcloud_role_id \
-               and self.overcloud_id == other.overcloud_id
+        return (self.overcloud_role_id == other.overcloud_role_id
+                and self.overcloud_id == other.overcloud_id)
 
 
 class OvercloudAttribute(Base):
@@ -148,7 +152,8 @@ class OvercloudAttribute(Base):
 
     # Reference back to the overcloud being configured
     overcloud_id = Column(Integer,
-                          ForeignKey('%s.id' % TABLE_OVERCLOUD),
+                          ForeignKey('%s.id' % TABLE_OVERCLOUD,
+                                     ondelete='CASCADE'),
                           nullable=False)
 
     # Identifier and value of the configuration attribute
@@ -156,8 +161,8 @@ class OvercloudAttribute(Base):
     value = Column(Text())
 
     def __eq__(self, other):
-        return self.overcloud_id == other.overcloud_id \
-               and self.key == other.key
+        return (self.overcloud_id == other.overcloud_id
+                and self.key == other.key)
 
 
 class Overcloud(Base):
@@ -182,10 +187,12 @@ class Overcloud(Base):
     description = Column(String(length=LENGTH_DESCRIPTION))
 
     # List of configuration attributes for the overcloud
-    attributes = relationship(OvercloudAttribute.__name__)
+    attributes = relationship(OvercloudAttribute.__name__,
+                              cascade='all,delete')
 
     # List of counts of overcloud roles to deploy
-    counts = relationship(OvercloudRoleCount.__name__)
+    counts = relationship(OvercloudRoleCount.__name__,
+                          cascade='all,delete')
 
     def __eq__(self, other):
         return self.name == other.name
